%%%%%%%%%%%%%%%%%
% Script Outline:
%%%%%%%%%%%%%%%%%%
% Step through each session, load the datafile, calculate the LL of each
% strategy for each subject in the session using calc_pis, append until 
% you have a matrix with one row for every subject in the entire paper 
% (across all treatments etc), and one column for each strategy.  
% Then pass this matrix to the calc_MLE function, which will return (for 
% each [b/c, error] pair) the estimated probability of choosing each 
% strategy, along with bootstrapped standard errors and p-values for whether 
% each strategy is different from 0.
%


%%%%%%%%%%%%%%%%%%%%%%%%%
% Define set of strategies to investigate (as per the key in calc_pis)

% Full 20 strategy set:
posStrats=[1 1 1 1 1 1 1 1; ...    % ALLC
    1 -1 1 -1 1 -1 1 -1; ...    % TFT
    1 1 1 1 1 -1 1 -1; ...  % TF2T
    -3*ones(1,8); ... % TF3T
    1 -1 1 -1 -1 -1 -1 -1; ... % 2TFT
    -2.2*ones(1,8); ... % 2TF2T
    -9*ones(1,8); ... % Grim
    -40*ones(1,8); ... % Grim-2
    -41*ones(1,8); ... % Grim-3 
    1 -1 -1 1 1 -1 -1 1; ... % PFTF
    -30*ones(1,8); ... % 2PTFT
    -99*ones(1,8); ... % T2
    -1 -1 -1 -1 -1 -1 -1 -1; ...  % ALLD
    -6*ones(1,8); ... %D-TFT
    -7*ones(1,8); ... %D-TF2t
    -7.1*ones(1,8); ... %D-TF3t
    (-7.2)*ones(1,8); ... D-Grim2
    (-7.3)*ones(1,8); ... D-Grim3
    -10*ones(1,8); ... %C-to-ALLD
    -8*ones(1,8); ... %DC-Alt
    ];

% 11 strategy subset:
posStrats=[1 1 1 1 1 1 1 1; ...    % ALLC
    1 -1 1 -1 1 -1 1 -1; ...    % TFT
    1 1 1 1 1 -1 1 -1; ...  % TF2T
    -3*ones(1,8); ... % TF3T
    1 -1 1 -1 -1 -1 -1 -1; ... % 2TFT
    -2.2*ones(1,8); ... % 2TF2T
    -9*ones(1,8); ... % Grim
    -40*ones(1,8); ... % Grim-2
    -41*ones(1,8); ... % Grim-3 
    -1 -1 -1 -1 -1 -1 -1 -1; ...  % ALLD
    -6*ones(1,8); ... %D-TFT
    ];
%%%%%%%%%%%%%%%%%%%%%%%%


% pisAll will hold the aggregated likelihoods for all subjects
pisAll=[];

for file=1:18    

    % Load the current datafile
    
    if file==1
        load data20100202_s2
        bc=1.5;
        error=1/8;
    elseif file==2
        load data20100204_s1
        bc=1.5;
        error=1/8;
    elseif file==3
        load data20100204_s2
        bc=1.5;
        error=1/8;        
    
    elseif file==4
        load data20100202_s1
        bc=2;
        error=1/8;
    elseif file==5
        load data20100202_s3
        bc=2;
        error=1/8;

    elseif file==6
        load data20091113_s1
        bc=2.5;
        error=1/8;
    elseif file==7
        load data20091113_s2
        bc=2.5;
        error=1/8;
    elseif file==8
        load data20091113_s3
        bc=2.5;
        error=1/8;
  
    elseif file==9
        load data20090929_s2
        bc=4;
        error=1/8;
    elseif file==10
        load data20091007
        bc=4;
        error=1/8;
    elseif file==11
        load data20091103_s1
        bc=4;
        error=1/8;
    elseif file==12
        load data20091103_s2
        bc=4;
        error=1/8;
          
    elseif file==13
        load data20101014_s1
        bc=4;
        error=1/16;        
    elseif file==14
        load data20101018_s1
        bc=4;
        error=1/16;        
    elseif file==15
        load data20101014_s3
        bc=4;
        error=1/16;
        
    elseif file==16
        load data20101014_s2
        bc=4;
        error=0;        
    elseif file==17
        load data20090929_s1
        bc=4;
        error=0;
    elseif file==18
        load data20101018_s2
        bc=4;
        error=0;        
    end
    
    
    numInteractions=max(data(:,1));
    numSubjects=max(data(:,3));
    
    % just analyze the last 4 interactions of each session
    startFrom=numInteractions-3;
    endAt=numInteractions;
    

    % calculate the likelihoods for this session
    pis=calc_pis(posStrats,startFrom,endAt,data,bc,error,numSubjects);
    
    % append to the growing list of pis results
    pisAll=[pisAll; pis];
    
end



% now that we've collected all the likelihoods, do the optimization
nBoots=50;
[MLE_estimates, SEs, pvals]=calc_MLE(pisAll,nBoots)
